options pagesize=100 linesize=200 compress=yes nocenter NODATE NONUMBER MPRINT MLOGIC;
      
libname out     'C:\Fred\AHS_03_05'; 
******************************************************************************************;
/*1.	Merge the 2003 and 2005 files, using the flat files.  
(N = 75,807) 

Eliminate non-matches (20,863).  */
******************************************************************************************;


/* proc sort data= OUT.NEW_AHS2003; by control; run;  
proc sort data= OUT.AHS2005; by control; run; 

DATA OUT.BOTH_AHS2003_AHS2005; MERGE OUT.NEW_AHS2003 (IN=ID3) 
 OUT.AHS2005 (IN=ID5); BY CONTROL;

IF ID3=1 AND ID5=1 THEN MATCH=1;
IF ID3=1 AND ID5=0 THEN MATCH=2;
IF ID3=0 AND ID5=1 THEN MATCH=3;

RUN;

proc freq data=OUT.BOTH_AHS2003_AHS2005;table match;run;*/
******************************************************************************************;

/**** FIND THE BASECOUNT ****/

DATA BOTH_AHS2003_AHS2005_1; SET OUT.BOTH_AHS_03_05_REDUCED;
IF MATCH=1;N=1; RUN;

PROC MEANS DATA=BOTH_AHS2003_AHS2005_1 N SUM ; VAR  IN03_PWT IN03_WGT90GEO; RUN;

******************************************************************************************;
/*2.	Eliminate all observations that were 2003 type B or type C losses 
(10 LE IN03_NOINT LE 38) and all observations that were deleted in the 2003 
prelist subsampling (IN03_NOINT=39).  These units were not part of the 2003 
stock and therefore are not tracked in the forward-looking analysis. (7880)*/

******************************************************************************************;


DATA BOTH_AHS2003_AHS2005_2; SET BOTH_AHS2003_AHS2005_1;

IF (10 LE IN03_NOINT LE 38) THEN DELETE;

IF (IN03_NOINT=39) THEN DELETE;RUN;

******************************************************************************************;
/*3.	For all units let MXPWT = max (IN05_PWT, IN03_PWT).   
(PWT is the pure weight). In general, the pure weights should not differ 
except in the six metropolitan areas with added sample in 2003 but not 2005.   
If there were an unusually low IN03_PWT for one or more observations, 
this step would adjust for that low value. */

******************************************************************************************;

DATA BOTH_AHS2003_AHS2005_2;SET  BOTH_AHS2003_AHS2005_2;
MXPWT = max(IN05_PWT, IN03_PWT);RUN;
******************************************************************************************;
/*4.	Adjust the pure weights for manufactured (mobile) homes.  

a.	From the 2003 file before merger, compute a pure weight count of mobile 
homes (MOBILEPUREALL = 7,056,688) by summing PWT for cases where IN03_NUNIT2 = 4. 

b.	From merged file, compute a pure weight count of mobile homes that are 
in both years (MOBILEPUREKEPT = 3,683,766) by summing MXPWT for cases where IN03_NUNIT2 = 4. 

c.	Adjust the pure weights of all manufactured (mobile). 
IF IN03_NUNIT2 = 4, 
MXPWT = MXPWT*(MOBILEPUREALL/MOBILEPUREKEPT)
MXPWT = MXPWT*(1.915617876)
*/
******************************************************************************************;
DATA SET1; SET OUT.BOTH_AHS_03_05_REDUCED ;IF MATCH=1 OR MATCH=2;
IF (IN03_NUNIT2 = '4'); RUN;
PROC MEANS DATA=SET1 N SUM ; VAR IN03_PWT; RUN;
DATA SET2; SET BOTH_AHS2003_AHS2005_2  ; IF (IN03_NUNIT2 = '4'); RUN;

PROC MEANS DATA=SET2 N SUM ; VAR MXPWT; RUN;

*****************************************************************************************;

DATA FORWARD_AHS2003_2005 ; SET BOTH_AHS2003_AHS2005_2;


IF (IN03_NUNIT2 = '4') THEN MXPWT = MXPWT*(7056688/3683766);RUN;

*****************************************************************************************;
/*
5.	Open from the published report an estimate of the 2003 stock 
(BASECOUNT = 120,777,000).  
(In the 2001/2003 algorithm, we obtained BASECOUNT using the final weight 
(IN03_ WGT90GEO).  This procedure would not be desirable for the 2003/2005 
analysis because we dropped so many mobile homes with non-zero IN03_ WGT90GEO.  
Frankly, it seems better to use the published total regardless.)
*/
******************************************************************************************;
/*6.	Compute SMXPWT = sum of MXPWT after step 4; this sum is a first estimate of 
the size of the housing stock based on the units retained for analysis. 
N= 53,608 and  SMXPWT =118,898,905 */
******************************************************************************************;

PROC MEANS DATA=FORWARD_AHS2003_2005 N SUM ; VAR MXPWT; RUN;

******************************************************************************************;
/*7.	Compute a FLCINCHWT = MXPWT*(BASECOUNT/SMXPWT).  
This computation ratios the weights up so that they sum to the 2003 stock. 
FLCINCHWT = MXPWT*(120,777,000/SMXPWT)      SUM OF FLCINCHWT=120777000*/
******************************************************************************************;

DATA FORWARD_AHS2003_2005 ;SET FORWARD_AHS2003_2005;

BASECOUNT=120777000;     /* FROM PUBLISHED NUMBERS*/
SMXPWT=118898905;      /*SMXPWT=sum of MXPWT after step 4 */
FLCINCHWT = MXPWT*(BASECOUNT/SMXPWT); RUN;

******************************************************************************************;

PROC MEANS DATA=FORWARD_AHS2003_2005 N SUM ; VAR FLCINCHWT ; RUN;
******************************************************************************************;

/*
8.	Identify sames, losses, and interviewed losses:

a.	SAME=1 if IN03_ISTATUS = 1, 2, or 3 AND IN05_ISTATUS = 1, 2, OR 3      N = 44,590

b.	LOSS = 1 if IN03_ISTATUS=1, 2, 3, or 4 AND 10 LE IN05_NOINT LE 38     N = 790

c.	INTLOSS = 1 if IN03_ISTATUS=1, 2, or 3 AND 10 LE IN05_NOINT LE 38     N = 748

*/

******************************************************************************************;

DATA FORWARD_AHS2003_2005 ;SET FORWARD_AHS2003_2005;

SAME=0;
IF (IN03_ISTATUS='1' OR IN03_ISTATUS='2' OR IN03_ISTATUS='3' )
AND (IN05_ISTATUS='1' OR IN05_ISTATUS='2' OR IN05_ISTATUS='3')  THEN SAME=1;

LOSS=0;
IF (IN03_ISTATUS='1' OR IN03_ISTATUS='2' OR IN03_ISTATUS='3' OR IN03_ISTATUS='4')
AND (10 LE IN05_NOINT LE 39) THEN LOSS=1;

INTLOSS=0;
IF (IN03_ISTATUS='1' OR IN03_ISTATUS='2' OR IN03_ISTATUS='3' )
AND (10 LE IN05_NOINT LE 39) THEN INTLOSS=1; RUN;

******************************************************************************************;
PROC FREQ DATA=FORWARD_AHS2003_2005;TABLE SAME LOSS INTLOSS; RUN;
******************************************************************************************;

DATA SAME1; SET  FORWARD_AHS2003_2005; IF SAME=1; RUN;

PROC SORT DATA=SAME1; BY N;RUN;

PROC MEANS DATA=SAME1 N  SUM  ; VAR FLCINCHWT;BY N;
OUTPUT OUT=S1 SUM=SSAMES; RUN;
 
DATA LOSS1; SET  FORWARD_AHS2003_2005; IF LOSS=1; RUN;

PROC SORT DATA=LOSS1; BY N; RUN;

PROC MEANS DATA=LOSS1 N  SUM ; VAR FLCINCHWT;BY N;
OUTPUT OUT=S2 SUM=SLOSSES; RUN;

DATA INTLOSS1; SET  FORWARD_AHS2003_2005; IF INTLOSS=1; RUN;

PROC SORT DATA=INTLOSS1 ; BY N; RUN;

PROC MEANS DATA=INTLOSS1 N  SUM ; VAR FLCINCHWT;BY N;  
OUTPUT OUT=S3 SUM=SINTLOSSES; RUN;

*******************************************************************************************;
/*9.	Calculate:

a.	SSAME = sum of FLCINCHWT for all SAME = 1 ( 1,006,812,861)

b.	SLOSS = sum of FLCINCHWT for all LOSS =1  (     1,946,235.18 )

c.	SINTLOSS =  sum of FLCINCHWT for INTLOSS = 1 (1,856,368.12)*/

*******************************************************************************************;
PROC SORT DATA= FORWARD_AHS2003_2005 ; BY N; RUN;
PROC SORT DATA=S1; BY N; RUN; 
PROC SORT DATA=S2; BY N; RUN; 
PROC SORT DATA=S3; BY N; RUN; 

******************************************************************************************;
/*
10.	Eliminate from subsequent analysis all observations that were 2003 
or 2005 type A noninterviews.  We cannot use the noninterviews because there 
is no information on the characteristics of these units.  
However, we retain them until this point so that we can get good estimates of 
the number of losses (SLOSS).


11.	Calculate:

a.	Ratio1 = (BASECOUNT  SLOSS)/SSAME (1.1843028)

b.	Ratio2 = SLOSS/SINTLOSS (1.0549755)

12.	Recalculate FLCINCHWT as follows:

a.	For SAME =1, FLCINCHWT = Ratio1*FLCINCHWT

b.	For INTLOSS =1, FLCINCHWT = Ratio2*FLCINCHWT 


*/
******************************************************************************************;

DATA  FORWARD_AHS2003_2005; MERGE  FORWARD_AHS2003_2005 S1 S2 S3; BY N;
RATIO1=(BASECOUNT-SLOSSES)/SSAMES;
RATIO2=SLOSSES/SINTLOSSES;

IF (1 LE IN03_NOINT LE 6) OR (1 LE IN05_NOINT LE 6) THEN DELETE;

IF SAME=1    THEN FLCINCHWT=FLCINCHWT*RATIO1;
IF INTLOSS=1 THEN FLCINCHWT=FLCINCHWT*RATIO2;RUN;

******************************************************************************************;
PROC MEANS DATA=FORWARD_AHS2003_2005 N MEAN ; VAR RATIO1 RATIO2; RUN;

******************************************************************************************;
/*

13.	From published reports obtain estimated 2003 counts for all owner-occupied 
units, all renter-occupied units, all vacant units, and all seasonal units.   

Calculate using the values in the table below: 

a.	Sum FLCINCHWT for all SAME = 1 or INTLOSS = 1 
in which IN03_ISTATUS = 1 (occupied units) AND IN03_TENURE = 1 (owner-occupied units).  
Ratio adjust the FLCINCHWT for these observations so that they sum to the published 
total for owner-occupied units.

b.	Sum FLCINCHWT for all SAME = 1 or INTLOSS = 1 in which IN03_ISTATUS = 1 
(occupied units) AND (2 LE IN03_TENURE LE 3) (renter-occupied units).  
Ratio adjust the FLCINCHWT for these observations so that they sum to the published 
total for renter-occupied units. 

c.	Sum FLCINCHWT for all SAME = 1 or INTLOSS = 1 in which 
(IN03_ISTATUS='2' OR IN03_ISTATUS='3') AND NOT (8 LE IN03_VACANCY LE 10) 
(URE and vacant units).  
Ratio adjust the FLCINCHWT for these observations so that they sum to the published 
total for vacant units.

d.	Sum FLCINCHWT for all SAME = 1 or INTLOSS = 1 in which 
(IN03_ISTATUS='2' OR IN03_ISTATUS='3') AND (8 LE IN03_VACANCY LE 10) (Seasonal units).  
Ratio adjust the FLCINCHWT for these observations so that they sum to the published 
total for seasonal units.

Table for step 13
	              Published
                      2003	        Sum of FLCINCHWT	Ratio Adjustment
Housing Stock	      120,777,000      120,777,000.00	                Not Used
Occupied	      105,842,000      103,327,123.28                  Not Used
   Owner-Occupied      72,238,000	70,947,772.05	               1.018185602 
   Renter	       33,604,000	32,379,351.23                  1.037821906
Vacant	               11,369,000	13,865,600.15                  0.819942871
Seasonal        	3,566,000	 3,584,276.57	               0.994900904
*/
********************************************************************************************;
DATA  FORWARD_AHS2003_2005; SET  FORWARD_AHS2003_2005;

IF (SAME = 1 OR INTLOSS = 1) AND IN03_ISTATUS='1' AND IN03_TENURE='1'                      
THEN GROUP=1; /*owner-occupied units*/

IF (SAME = 1 OR INTLOSS = 1) AND IN03_ISTATUS='1' AND (IN03_TENURE='2' OR IN03_TENURE='3') 
THEN GROUP=2; /*renter-occupied units */

IF (SAME = 1 OR INTLOSS = 1) AND (IN03_ISTATUS='2' OR IN03_ISTATUS='3') AND 
NOT(8 LE IN03_VACANCY LE 11) THEN GROUP=3; /*URE and vacant units*/

IF (SAME = 1 OR INTLOSS = 1) AND (IN03_ISTATUS='2' OR IN03_ISTATUS='3' ) AND 
(8 LE IN03_VACANCY LE 11)   THEN GROUP=4; /*Seasonal units*/;
RUN;

********************************************************************************************;
PROC FREQ DATA=FORWARD_AHS2003_2005; TABLE GROUP; RUN;

PROC SORT DATA=FORWARD_AHS2003_2005 ; BY GROUP; RUN;

PROC MEANS DATA= FORWARD_AHS2003_2005 N SUM; VAR FLCINCHWT; BY GROUP;
OUTPUT OUT=G SUM=SUM_FLCINCHWT; RUN;

PROC SORT DATA=G; BY GROUP; RUN;
DATA  FORWARD_AHS2003_2005; MERGE  FORWARD_AHS2003_2005 G; BY GROUP; 

IF GROUP=1 THEN
FLCINCHWT=FLCINCHWT*(72238000/SUM_FLCINCHWT);

IF GROUP=2 THEN
FLCINCHWT=FLCINCHWT*(33604000/SUM_FLCINCHWT);

IF GROUP=3 THEN
FLCINCHWT=FLCINCHWT*(11369000/SUM_FLCINCHWT);

IF GROUP=4 THEN
FLCINCHWT=FLCINCHWT*(3566000/SUM_FLCINCHWT); RUN;
********************************************************************************************;

PROC MEANS DATA=FORWARD_AHS2003_2005 N SUM MEAN ; VAR FLCINCHWT ; RUN;

PROC SORT DATA=FORWARD_AHS2003_2005; BY GROUP; RUN;

PROC MEANS DATA=FORWARD_AHS2003_2005 N SUM MEAN; VAR  FLCINCHWT ;
 BY GROUP;RUN;
********************************************************************************************;
/*14.	Sum of FLCINCHWT after final weighting:

	         N   	Sum of FLCINCHWT
SAME	     44,590	118,941,102
INTLOSS 	748	  1,835,898.25 
Total	     45,338	120,777,000*/

*******************************************************************************************;
DATA SAME1; SET FORWARD_AHS2003_2005 ; IF SAME=1; RUN;

PROC MEANS DATA=SAME1 N SUM MEAN ; VAR FLCINCHWT ; RUN;

DATA LOSS1; SET  FORWARD_AHS2003_2005; IF LOSS=1; RUN;

PROC MEANS DATA=LOSS1 N SUM MEAN ; VAR FLCINCHWT ; RUN;

*******************************************************************************************;
/*
When you are finished, please calculate the sum of FLCINCHWT for 
NUNIT2 = 4  and for NUNIT2 = 1.
*/
*******************************************************************************************;
Title ' Sum of FLCINCHWT for IN03_NUNIT2 = 4  ';RUN;
DATA SET1; SET FORWARD_AHS2003_2005; IF IN03_NUNIT2 = '4'; RUN;

PROC MEANS DATA=SET1 N SUM ; VAR FLCINCHWT ; RUN;

Title ' Sum of FLCINCHWT for for IN03_NUNIT2 = 1';RUN;
DATA SET2; SET FORWARD_AHS2003_2005; IF IN03_NUNIT2 = '1'; RUN;

PROC MEANS DATA=SET2 N SUM ; VAR FLCINCHWT ; RUN;
*******************************************************************************************;
DATA OUT.FORWARD_AHS2003_2005; SET FORWARD_AHS2003_2005; 
/***** FLSTATUS CODE *****/
/*FLSTATUS = Forward status = status of a 2003 unit in 2005
1 = in 2003 stock and in 2005 stock (SAME=1)

2 = in 2003 stock but a loss in 2005 due to conversion or merger
 (INTLOSS=1 AND 32 LE IN05_NOINT LE 33)

3 = in 2003 stock but a loss in 2005 due to house or mobile home move out 
(INTLOSS=1 AND IN05_NOINT = 31)

4 = in 2003 stock but a loss in 2005 due to nonresidential use 
(INTLOSS=1 AND (IN05_NOINT = 12 OR IN05_NOINT = 14))

5 = in 2003 stock but a loss in 2005 due to demolition or disaster 
(INTLOSS=1 AND IN05_NOINT = 30)

6 = in 2003 stock but a loss in 2005 due to damage or condemnation 
(INTLOSS=1 AND 15 LE IN05_NOINT LE 16)

7 = in 2003 stock but a loss in 2005 for other reason 
(INTLOSS=1 AND (10 LE IN05_NOINT LE 11 OR IN05_NOINT=13 OR IN05_NOINT=17 OR
 36 LE IN05_NOINT LE 39))

*/

IF SAME=1 THEN FLSTATUS=1;

IF INTLOSS=1 AND (32 LE IN05_NOINT LE 33) THEN FLSTATUS=2; /*merging or conversion*/ 

IF INTLOSS=1 AND (IN05_NOINT=31) THEN FLSTATUS=3; /* house or mobile home moved */

IF INTLOSS=1 AND (IN05_NOINT=12 OR IN05_NOINT=14) THEN FLSTATUS=4; /* nonresidential */

IF INTLOSS=1 AND (IN05_NOINT=30) THEN FLSTATUS=5; /* demolished or destroyed */

IF INTLOSS=1 AND (15 LE IN05_NOINT LE 16) THEN FLSTATUS=6; /* uninhabit */

IF INTLOSS=1 AND ((10 LE IN05_NOINT LE 11) OR IN05_NOINT=13 OR IN05_NOINT=17 OR 
(36 LE IN05_NOINT LE 39)) THEN FLSTATUS=7;  /* other */


RUN;
PROC CONTENTS DATA=OUT.FORWARD_AHS2003_2005; RUN;

